@@ -54,6 +54,11 @@ class MongoTests(unittest.TestCase):
         except:
             raise unittest.SkipTest('MongoDB is not running in localhost:27017! Skipping tests.')
 
+    @classmethod
+    def tearDownClass(cls):
+        if cls.lp:
+            cls.lp.connection.drop_database(TESTDB_NAME)
+
     def _teardown(self, dests):
         for f in dests:
             if os.path.exists(f):
@@ -69,7 +74,7 @@ class MongoTests(unittest.TestCase):
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data[
-            'stdout'], str(six.b('test1\n')))
+            'stdout'], 'test1\n')
 
     def test_multi_fw(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'",
@@ -81,7 +86,7 @@ class MongoTests(unittest.TestCase):
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(
             self.lp.get_launch_by_id(1).action.stored_data['stdout'],
-            str(six.b("test2\n")))
+            "test2\n")
 
     def test_multi_fw_complex(self):
 
@@ -143,10 +148,10 @@ class MongoTests(unittest.TestCase):
         self.lp.add_wf(wf)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data['stdout'],
-                         str(six.b('test1\n')))
+                         'test1\n')
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(2).action.stored_data['stdout'],
-                         str(six.b('test2\n')))
+                         'test2\n')
 
     def test_fibadder(self):
         fib = FibonacciAdderTask()
@@ -203,9 +208,9 @@ class MongoTests(unittest.TestCase):
 
     def tearDown(self):
         self.lp.reset(password=None, require_password=False)
-        os.chdir(self.old_wd)
         if os.path.exists(os.path.join('FW.json')):
             os.remove('FW.json')
+        os.chdir(self.old_wd)
         for i in glob.glob(os.path.join(MODULE_DIR, 'launcher*')):
             shutil.rmtree(i)
 
